@@ -19,15 +19,17 @@ use simplelog::{ConfigBuilder, LevelFilter, SimpleLogger};
 use std::sync::Once;
 
 pub mod average;
+pub mod config;
 pub mod fmt;
 pub mod platform;
+pub mod server;
 pub mod signals;
 
 /// Contains the version of the Apollo framework.
-pub const APOLLO_VERSION: &str = "0.1.0";
+pub const APOLLO_VERSION: &str = "0.2.0";
 
 /// Contains the git commit hash of the Apollo build being used.
-pub const APOLLO_REVISION: &str = "2e1c87acff7699dca3b3d5dd29048efb625819d3";
+pub const APOLLO_REVISION: &str = "de6db0e42cb529e40927e49ca3c681c14195db11";
 
 /// Initializes the logging system.
 ///
@@ -53,3 +55,29 @@ pub fn init_logging() {
         }
     });
 }
+
+#[cfg(test)]
+mod testing {
+    use std::sync::Mutex;
+
+    lazy_static::lazy_static! {
+        /// Provides a global lock which has to be acquired if a test operates on shared
+        /// resources. This would either be our test port (1503) on which we start our
+        /// local server for integrations tests or the repository which operates on the
+        /// file system. Using this lock, we can still execute all other tests in parallel
+        /// and only block if required.
+        pub static ref SHARED_TEST_RESOURCES: Mutex<()> = Mutex::new(());
+    }
+
+    /// Executes async code within a single threaded tokio runtime.
+    pub fn test_async<F: std::future::Future>(future: F) {
+        use tokio::runtime;
+
+        let rt = runtime::Builder::new_current_thread()
+            .enable_all()
+            .build()
+            .unwrap();
+
+        let _ = rt.block_on(future);
+    }
+}
